@@ -149,46 +149,36 @@ class Checker:
                     password = combo.split(";")[1]
             except queue.Empty:
                 return
+            while True:
+                result = check(email, password, proxy)
+                match result[0]:
+                    case "good":
+                        self.data["hits"] += 1
+                        self.data["checked"] += 1
+                        if self.mode == "log":
+                            if self.capture:
+                                print(f"[{COLORS['green']}+{RESET}] {COLORS['green']}-{RESET} {combo} | {result[1]}")
+                            else:
+                                print(f"[{COLORS['green']}+{RESET}] {COLORS['green']}-{RESET} {combo}")
+                    case "bad":
+                        self.data["bad"] += 1
+                        self.data["checked"] += 1
+                        q.task_done()
+                        break
+                    case "custom":
+                        self.data["custom"] += 1
+                        self.data["checked"] += 1
+                        if self.mode == "log":
+                            print(f"[{COLORS['yellow']}+{RESET}] {COLORS['yellow']}-{RESET} {combo}")
 
-            result = check(email, password, proxy)
-            match result[0]:
-                case "good":
-                    self.data["hits"] += 1
-                    self.data["checked"] += 1
-                    if self.mode == "log":
-                        if self.capture:
-                            print(f"[{COLORS['green']}+{RESET}] {COLORS['green']}-{RESET} {combo} | {result[1]}")
-                        else:
-                            print(f"[{COLORS['green']}+{RESET}] {COLORS['green']}-{RESET} {combo}")
-                case "bad":
-                    self.data["bad"] += 1
-                    self.data["checked"] += 1
-                case "custom":
-                    self.data["custom"] += 1
-                    self.data["checked"] += 1
-                    if self.mode == "log":
-                        print(f"[{COLORS['yellow']}+{RESET}] {COLORS['yellow']}-{RESET} {combo}")
-                case "retry":
-                    self.data["retries"] += 1
-                    self.worker(check, q, proxy)
-                case "error":
-                    self.data["errors"] += 1
-                    self.worker(check, q, proxy)
-                case _:
-                    raise TypeError
-
-            '''
-            Your check function must return the following strings:
-            - "good"
-            - "bad"
-            - "custom"
-            - "retry"
-            - "error"
-
-            Failure to do so will raise an error
-            '''
-
-            q.task_done()
+                        q.task_done()
+                        break
+                    case "retry":
+                        self.data["retries"] += 1
+                    case "error":
+                        self.data["errors"] += 1
+                    case _:
+                        raise TypeError
 
     def run(self, check):
         self.initialise_console()
